import React, { useEffect, useState } from 'react';
import { Alert } from 'react-native';
import { Modal } from 'react-native';
import {
  KeyboardAvoidingView,
  Platform,
  SafeAreaView,
  Keyboard,
  Image,
} from 'react-native';
import { TouchableOpacity } from 'react-native';
import { View, Text, TextInput, StyleSheet } from 'react-native';

interface BioProps {
  onChangeText: (params: any) => any;
  value: string;
  onPress: (params: any) => any;
  onBlur: (params: any) => any;
  onChange: (params: any) => any;
  onFocus: (params: any) => any;
  buttonText: string;
  source?: JSX.Element;
  keyboardType: any;
  input: any;
  editable: boolean;
  placeholder: string;
  multiline: boolean;
  autoCapitalize: any;
  returnKeyType: any;
  placeholderTextColor: string;
  numberOfLines: number;
  maxLength: number;
  autoFocus: boolean;
  blurOnSubmit: boolean;
  enablesReturnKeyAutomatically: boolean;
  returnKeyLabel: string;
  secureTextEntry: boolean;
  textAlign: any;
  ImageViewStyle: any;
  ContainerViewStyle: any;
  ImageStyle: any;
  MainView: any;
  TextStyle: any;
  InputBoxStyle: any;
  ButtonViewStyle: any;
  ButtonTextStyle: any;
  button: boolean;
  SignupButton: boolean;
  SignupTextStyle: any;
  SingupStyle: any;
  SingupText: string;
  Singup: string;
  SingupClick: (params: any) => any;
  LoginText: string;
  valueOTP:string;
  onChangeTextOTP:(params: any) => any;
  placeholderOTP:string
  placeholderTextColorOTP:string;
  editableOTP:boolean
  autoFocusOTP:boolean
  blurOnSubmitOTP:boolean
  enablesReturnKeyAutomaticallyOTP:boolean
  onBlurOTP:(params: any) => any;
  onFocusOTP:(params: any) => any;
  onChangeOTP:(params: any) => any;
  secureTextEntryOTP:boolean
  ResendOTP:string
  DontOTP:string
  ResendButton:boolean
  buttonTextOTP:string
  onPressOTP:(params: any) => any;
  ResendButtonClick:(params: any) => any;
  LoginTextOTP:string
  modalVisible:boolean
  doneButton:(params: any) => any;

}

const Sandy: React.FC<BioProps> = (props): JSX.Element => {
  const [isKeyboardVisible, setKeyboardVisible] = useState(false);
  const [modalVisible, setModalVisible] = useState(props.modalVisible || false);

  console.log("modalVisible---",props.modalVisible,modalVisible)

  useEffect(() => {
    const keyboardDidShowListener = Keyboard.addListener(
      'keyboardDidShow',
      () => {
        setKeyboardVisible(true); // or some other action
      }
    );
    const keyboardDidHideListener = Keyboard.addListener(
      'keyboardDidHide',
      () => {
        setKeyboardVisible(false); // or some other action
      }
    );

    return () => {
      keyboardDidHideListener.remove();
      keyboardDidShowListener.remove();
    };
  }, []);
  return (
    <>
      <SafeAreaView style={{ flex: 1 }}>
        <KeyboardAvoidingView
          behavior={Platform.OS == 'android' ? 'height' : 'padding'}
        >
          <View
            style={[
              {
                height: '100%',
                width: '100%',
                // justifyContent: 'center',
              },
              props.MainView,
            ]}
          >
            {props.source ? (
              <View
                style={[
                  {
                    height: isKeyboardVisible ? '40%' : '60%',
                    width: '100%',
                    alignSelf: 'center',
                    justifyContent: 'center',
                  },
                  props.ImageViewStyle,
                ]}
              >
                <Image
                  source={props.source ? props.source : require('./a.jpeg')}
                  style={[
                    styles.backgroundImage,
                    {
                      height: isKeyboardVisible ? 80 : 150,
                      width: isKeyboardVisible ? 80 : 150,
                    },
                    props.ImageStyle,
                  ]}
                />
              </View>
            ) : null}
            <View style={[styles.viewa, props.ContainerViewStyle]}>
             {props.modalVisible?null:
             <>
             <Text style={[styles.title, props.TextStyle]}>
                {props.LoginText || 'Login'}
              </Text>

              <View style={styles.inputContainer}>
                <TextInput
                  numberOfLines={props.numberOfLines || 1}
                  maxLength={props.maxLength || 50}
                  onChangeText={props.onChangeText}
                  value={props.value}
                  style={[styles.input, props.InputBoxStyle]}
                  returnKeyType={props.returnKeyType || 'done'}
                  keyboardType={props.keyboardType || 'default'}
                  placeholder={props.placeholder || 'write here... '}
                  placeholderTextColor={props.placeholderTextColor || 'grey'}
                  editable={props.editable || true}
                  multiline={props.multiline || false}
                  autoCapitalize={props.autoCapitalize || 'none'}
                  autoFocus={props.autoFocus || false}
                  blurOnSubmit={props.blurOnSubmit || false}
                  enablesReturnKeyAutomatically={
                    props.enablesReturnKeyAutomatically || false
                  }
                  onSubmitEditing={props.doneButton}
                  onBlur={props.onBlur}
                  onChange={props.onChange}
                  onFocus={props.onFocus}
                  returnKeyLabel={props.returnKeyLabel || 'default'}
                  secureTextEntry={props.secureTextEntry || false}
                  textAlign={props.textAlign || 'left'}
                />
              </View>
              </>
}
              {props.button && props.modalVisible==false ? (
                <TouchableOpacity
                  onPress={props.onPress}
                  style={[styles.buttonView, props.ButtonViewStyle]}
                >
                  <Text style={[styles.buttonText, props.ButtonTextStyle]}>
                    {props.buttonText || 'Continue'}
                  </Text>
                </TouchableOpacity>
              ) : null}
              {props.SignupButton && props.modalVisible==false ? (
                <Text
                  style={[
                    styles.title,
                    { fontSize: 15, textAlign: 'center', marginTop: 10 },
                    props.SignupTextStyle,
                  ]}
                >
                  {props.SingupText || "Don't have an account? "}
                  <Text
                    onPress={props.SingupClick}
                    style={[
                      { fontSize: 15, fontWeight: 'bold' },
                      props.SingupStyle,
                    ]}
                  >
                    {props.Singup || 'Sign Up'}
                  </Text>
                </Text>
              ) : null}
            </View>
          </View>
          {props.modalVisible ? (
            <>
              <Modal
                animationType="slide"
                transparent={true}
                visible={props.modalVisible}
                onRequestClose={() => {
                  Alert.alert('Modal has been closed.');
                  setModalVisible(!modalVisible);
                }}
              >
                <View style={styles.centeredView}>
                  <View style={styles.modalView}>
                  <Text style={[styles.title, props.TextStyle]}>
                {props.LoginTextOTP || 'Verify your OTP here'}
              </Text>
              <View style={styles.inputContainer}>
                    <TextInput
                  
                      maxLength={6}
                      onChangeText={props.onChangeTextOTP}
                      value={props.valueOTP}
                      style={[styles.input, props.InputBoxStyle]}
                      returnKeyType={props.returnKeyType || 'done'}
                      keyboardType={'number-pad'}
                      placeholder={props.placeholderOTP || 'enter otp here... '}
                      placeholderTextColor={props.placeholderTextColorOTP || 'grey'}
                      editable={props.editableOTP || true}
                      multiline={false}
                      autoCapitalize={'none'}
                      autoFocus={props.autoFocusOTP || false}
                      blurOnSubmit={props.blurOnSubmitOTP || false}
                      enablesReturnKeyAutomatically={
                        props.enablesReturnKeyAutomaticallyOTP || false
                      }
                      onBlur={props.onBlurOTP}
                      onChange={props.onChangeOTP}
                      onFocus={props.onFocusOTP}
                      returnKeyLabel={props.returnKeyLabel || 'default'}
                      secureTextEntry={props.secureTextEntryOTP || true}
                      textAlign={props.textAlign || 'left'}
                    
                    />
                    </View>
                   {props.ResendButton ? (
                <TouchableOpacity
                  onPress={props.onPressOTP}
                  style={[styles.buttonView, props.ButtonViewStyle]}
                >
                  <Text style={[styles.buttonText, props.ButtonTextStyle]}>
                    {props.buttonTextOTP || 'Continue'}
                  </Text>
                </TouchableOpacity>
              ) : null}
              {props.ResendButton   ? (
                <Text
                  style={[
                    styles.title,
                    { fontSize: 15, textAlign: 'center', marginTop: 10 },
                    props.SignupTextStyle,
                  ]}
                >
                  {props.DontOTP || "Don't received an OTP yet? "}
                  <Text
                    onPress={props.ResendButtonClick}
                    style={[
                      { fontSize: 15, fontWeight: 'bold' },
                      props.SingupStyle,
                    ]}
                  >
                    {props.ResendOTP || 'Resend OTP'}
                  </Text>
                </Text>
              ) : null}
                  </View>
                </View>
              </Modal>
            </>
          ) : null}
        </KeyboardAvoidingView>
      </SafeAreaView>
    </>
  );
};

const styles = StyleSheet.create({
  backgroundImage: {
    borderRadius: 10,
    alignSelf: 'center',
    resizeMode: 'cover',
    alignItems: 'center',
    // or 'stretch' for a different background image behavior
  },
  viewa: {
    alignSelf: 'center',
    width: '90%',
    height: 'auto',
    // backgroundColor:'red',
    position: 'absolute',
    bottom: 10,
  },
  inputContainer: {
    flexDirection: 'row',
    alignItems: 'center',
    marginBottom: 10,
  },

  buttonView: {
    height: 40,
    width: '100%',
    borderRadius: 10,
    backgroundColor: 'green',
    justifyContent: 'center',
    // padding: 10,
    shadowColor: '#000000',
    shadowOffset: {
      width: 1,
      height: 1,
    },
    elevation: 5,
    shadowRadius: 2,
    shadowOpacity: 0.2,
    borderWidth: 0.3,
  },
  buttonText: {
    textAlign: 'center',
    color: 'white',
    fontSize: 15,
    fontWeight: '600',
  },
  title: {
    fontSize: 25,
    color: 'black',
    marginBottom: 20,
  },

  input: {
    width: '100%',
    height: 40,
    backgroundColor: 'white',
    paddingLeft: 10,
    // marginBottom: 10,
    padding: 10,
    shadowColor: '#000000',
    shadowOffset: {
      width: 1,
      height: 1,
    },
    elevation: 5,
    shadowRadius: 2,
    shadowOpacity: 0.2,
    borderWidth: 0.3,
    borderRadius: 10,
  },
  centeredView: {
    flex: 1,
    justifyContent: 'flex-end',
    alignItems: 'center',
    // backgroundColor:'red',
  },
  modalView: {
    paddingTop: 10,
    paddingBottom: 10,
    justifyContent: 'center',
    width: '90%',

    // shadowColor: '#000',
    // shadowOffset: {
    //   width: 0,
    //   height: 2,
    // },
    // shadowOpacity: 0.25,
    // shadowRadius: 4,
    elevation: 5,
  },
  button: {
    borderRadius: 20,
    padding: 10,
    elevation: 2,
  },
  buttonOpen: {
    backgroundColor: '#F194FF',
  },
  buttonClose: {
    backgroundColor: '#2196F3',
  },
  textStyle: {
    color: 'white',
    fontWeight: 'bold',
    textAlign: 'center',
  },
  modalText: {
    marginBottom: 10,
    marginTop: 10,
    textAlign: 'left',
    width: '90%',
    alignSelf: 'center',
  },
});

export default Sandy;
